==> haskell-cryptohash-conduit-0.1.1-362-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-conduit
version:              0.1.1
visibility:           public
id:                   cryptohash-conduit-0.1.1-GDqNO5PxL6n2w75gtBEuFy
key:                  cryptohash-conduit-0.1.1-GDqNO5PxL6n2w75gtBEuFy
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cryptohash-conduit
synopsis:             cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.

category:             Cryptography, Conduit
abi:                  9dde2cea8e238af4f11afe169e6e057b
exposed:              True
exposed-modules:      Crypto.Hash.Conduit
import-dirs:          /usr/lib/ghc-8.10.1/site-local/cryptohash-conduit-0.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/cryptohash-conduit-0.1.1
hs-libraries:         HScryptohash-conduit-0.1.1-GDqNO5PxL6n2w75gtBEuFy
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    conduit-1.3.2-K70gZBL2fHy7pAwoErzAGH
    conduit-extra-1.3.5-GrHiz6L0uHQFmr6aHgpxSr
    cryptohash-0.11.9-x8n1ZKCPA370VwFly9paZ
    resourcet-1.2.4-KKyjWH4kPVsHTBug5svVkU transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-366-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-conduit
version:              0.1.1
visibility:           public
id:                   cryptohash-conduit-0.1.1-9FSXc4AKznbFXuTLwKFtW
key:                  cryptohash-conduit-0.1.1-9FSXc4AKznbFXuTLwKFtW
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cryptohash-conduit
synopsis:             cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.

category:             Cryptography, Conduit
abi:                  a37b119e2cc67084b074a511c6126d10
exposed:              True
exposed-modules:      Crypto.Hash.Conduit
import-dirs:          /usr/lib/ghc-8.10.1/site-local/cryptohash-conduit-0.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/cryptohash-conduit-0.1.1
hs-libraries:         HScryptohash-conduit-0.1.1-9FSXc4AKznbFXuTLwKFtW
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    conduit-1.3.2-HMrVpwE3Sq06WgUfKqbr9n
    conduit-extra-1.3.5-EQdwIDsj8nu89vsWZK6ebK
    cryptohash-0.11.9-x8n1ZKCPA370VwFly9paZ
    resourcet-1.2.4-D9lelWYYOwO39oUPVIVnqn transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
